@@ -1,4 +1,3 @@
-#  coding: utf-8
 # copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
@@ -58,7 +57,7 @@ def agency_id(self, agency):
 
 SEDAArchiveTransferIClonableAdapter.__select__ &= is_in_state('published')
 SEDAArchiveTransferIClonableAdapter.rtype = 'new_version_of'
-SEDAArchiveTransferIClonableAdapter.skiprtypes += ('clone_of',)
+SEDAArchiveTransferIClonableAdapter.skiprtypes += ('clone_of', 'used', 'generated')
 
 
 class SEDAArchiveTransfer(SEDAArchiveTransfer):
