@@ -59,32 +59,40 @@ class CWURIURLTC(unittest.TestCase):
 
 class SEDAExportTC(CubicWebTC):
 
+    def iter_seda_xsd(self, transfer):
+        """Yield XSD representations of the transfer for SEDA 0.2 then 1.0,
+        within a subTest.
+        """
+        for adapter_id in ('SEDA-0.2.xsd', 'SEDA-1.0.xsd'):
+            with self.subTest(adapter=adapter_id):
+                adapter = transfer.cw_adapt_to(adapter_id)
+                yield adapter.dump()
+
     def test_include_profile_ark(self):
         with self.admin_access.client_cnx() as cnx:
             transfer = testutils.seda_transfer(cnx)
             testutils.create_archive_unit(transfer)
             cnx.commit()
-            for adapter_id in ('SEDA-0.2.xsd', 'SEDA-1.0.xsd'):
-                with self.subTest(adapter=adapter_id):
-                    adapter = transfer.cw_adapt_to(adapter_id)
-                    xml = adapter.dump()
-                    self.assertIn('ArchivalProfile', xml)
-                    self.assertIn(transfer.ark, xml)
+            for xml in self.iter_seda_xsd(transfer):
+                self.assertIn('ArchivalProfile', xml)
+                self.assertIn('ark:/' + transfer.ark, xml)
 
-    def test_include_agent_ark(self):
+    def test_include_agency_ark(self):
         with self.admin_access.client_cnx() as cnx:
-            record = testutils.authority_record(cnx, u'DGSI')
-
             transfer = testutils.seda_transfer(cnx)
             _, _, unit_alt_seq = testutils.create_archive_unit(transfer)
-            cnx.create_entity('SEDAOriginatingAgency', seda_originating_agency_from=unit_alt_seq,
-                              seda_originating_agency_to=record)
+            agency = cnx.create_entity('SEDAOriginatingAgency',
+                                       seda_originating_agency_from=unit_alt_seq)
 
-            for adapter_id in ('SEDA-0.2.xsd', 'SEDA-1.0.xsd'):
-                with self.subTest(adapter=adapter_id):
-                    adapter = transfer.cw_adapt_to(adapter_id)
-                    xml = adapter.dump()
-                    self.assertIn(record.ark, xml)
+            # ensure it doesn't crash if agency is not tight to an authority record
+            for xml in self.iter_seda_xsd(transfer):
+                self.assertIn('OriginatingAgency', xml)
+
+            # ensure we get the ark as agency identifier
+            record = testutils.authority_record(cnx, u'DGSI')
+            agency.cw_set(seda_originating_agency_to=record)
+            for xml in self.iter_seda_xsd(transfer):
+                self.assertIn('ark:/' + record.ark, xml)
 
 
 if __name__ == '__main__':
